@@ -46,10 +46,13 @@ from .liouvillespace.relaxationtensor import RelaxationTensor
 # Relaxation tensors (weak SB theory)
 from .liouvillespace.redfieldtensor import RedfieldRelaxationTensor
 from .liouvillespace.tdredfieldtensor import TDRedfieldRelaxationTensor
-
+# Relaxation tensors (mixed theory)
+from .liouvillespace.modredfieldtensor import ModRedfieldRelaxationTensor
+from .liouvillespace.tdmodredfieldtensor import TDModRedfieldRelaxationTensor
 # Relaxation tensors (strong SB theory)
 from .liouvillespace.foerstertensor import FoersterRelaxationTensor
 from .liouvillespace.tdfoerstertensor import TDFoersterRelaxationTensor
+from .liouvillespace.nefoerstertensor import NEFoersterRelaxationTensor
 
 # Combined theories
 from .liouvillespace.redfieldfoerster import RedfieldFoersterRelaxationTensor
@@ -63,6 +66,9 @@ from .liouvillespace.puredephasing import PureDephasing
 from .liouvillespace.puredephasing import ElectronicPureDephasing
 
 
+from .liouvillespace.heom import KTHierarchy
+from .liouvillespace.heom import KTHierarchyPropagator
+
 from .liouvillespace.evolutionsuperoperator import EvolutionSuperOperator
 from .liouvillespace.superoperator import SuperOperator
 from .liouvillespace.superoperator_test import TestSuperOperator
