@@ -7,7 +7,7 @@
     -------------
     
 """
-import time
+#import time
 import numpy
 import scipy
 
@@ -19,7 +19,7 @@ from ...core.managers import  energy_units
 from ...core.parallel import block_distributed_range
 from ...core.parallel import start_parallel_region, close_parallel_region
 from ...core.parallel import distributed_configuration
-from ...core.managers import BasisManaged
+#from ...core.managers import BasisManaged
 from ...utils.types import BasisManagedComplexArray
 
 import quantarhei as qr
@@ -128,6 +128,10 @@ class RedfieldRelaxationTensor(RelaxationTensor):
                 self._implementation(ham, sbi)   
                 
 
+        self.Iterm = None
+        self.has_Iterm = False
+
+
     def apply(self, oper, copy=True):
         """Applies the relaxation tensor on a superoperator
         
@@ -246,11 +250,16 @@ class RedfieldRelaxationTensor(RelaxationTensor):
         #
         multi_ex = False
         
-        # figure out if the aggregate specifies more than one exciton band
+        # figure out if the aggregate or molecule specifies more than
+        # one exciton band
         if sbi.aggregate is not None:
             agg = sbi.aggregate
             if agg.mult > 1:
                 multi_ex = True 
+        elif sbi.molecule is not None:
+            mol = sbi.molecule
+            if mol.mult > 1:
+                multi_ex = True
         
         #
         # shorten the interval of integration if a cut-off time is set
