@@ -19,6 +19,9 @@ class RelaxationTensor(SuperOperator, Secular, Saveable):
         self._data_initialized = False
         self.name = ""
         self.as_operators = False
+        
+        self.Iterm = None
+        self.has_Iterm = False
 
  
     def _initialize_basis(self):
@@ -184,7 +187,7 @@ class RelaxationTensor(SuperOperator, Secular, Saveable):
             # dephasing rates 
             for nn in range(self.dim):    
                 for mm in range(nn+1,self.dim):
-                    self._data[nn,mm,nn,mm] = -(self._data[nn,nn,nn,nn]
+                    self._data[nn,mm,nn,mm] = (self._data[nn,nn,nn,nn]
                                               +self._data[mm,mm,mm,mm])/2.0
                     self._data[mm,nn,mm,nn] = self._data[nn,mm,nn,mm] 
 
@@ -201,7 +204,7 @@ class RelaxationTensor(SuperOperator, Secular, Saveable):
             # dephasing rates 
             for nn in range(self.dim):    
                 for mm in range(nn+1,self.dim):
-                    self._data[:,nn,mm,nn,mm] = -(self._data[:,nn,nn,nn,nn]
+                    self._data[:,nn,mm,nn,mm] = (self._data[:,nn,nn,nn,nn]
                                               +self._data[:,mm,mm,mm,mm])/2.0
                     self._data[:,mm,nn,mm,nn] = self._data[:,nn,mm,nn,mm] 
             
