@@ -794,6 +794,12 @@ class FluorSpectrumCalculator(EnergyUnitsManaged):
         
         """
         ta = self.TimeAxis
+        
+        
+        # FIXME: transition frequencies have to be calculate from the full
+        #        Hamiltonian
+        
+        HH = self.system.get_Hamiltonian()
         # transition frequency
         om = self.system.elenergies[1]-self.system.elenergies[0]
         # transition dipole moment
@@ -806,7 +812,7 @@ class FluorSpectrumCalculator(EnergyUnitsManaged):
         if self.system._has_system_bath_coupling:
             # correlation function
             ct = self.system.get_egcf((0,1))   
-            sbi = self.system.get_SystemBathInteraction(ta)
+            sbi = self.system.get_SystemBathInteraction() #(ta)
             re = sbi.CC.get_reorganization_energy(0,0)
             tr = {"ta":ta,"dd":dd,"om":om-self.rwa,"ct":ct,"gg":gama, "re":re}
         else:
